# Generated by Django 2.2.6 on 2019-10-08 17:02

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0030_user_color'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='props',
            field=bitfield.models.BitField((('bot', 'Системный пользователь'),), db_index=True, default=0),
        ),
    ]
