# Generated by Django 2.2 on 2019-04-14 09:20

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0013_auto_20190414_0919'),
    ]

    operations = [
        migrations.AlterField(
            model_name='messages',
            name='lastmodified',
            field=models.DateTimeField(default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление'),
        ),
        migrations.AlterField(
            model_name='messages_state',
            name='lastmodified',
            field=models.DateTimeField(default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление'),
        ),
        migrations.AlterField(
            model_name='messages_theme',
            name='lastmodified',
            field=models.DateTimeField(default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление'),
        ),
    ]
