# Generated by Django 2.1.7 on 2019-03-07 01:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0011_auto_20190307_0056'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='params',
            options={'verbose_name': 'Сохраненные параметры'},
        ),
    ]
