# Generated by Django 2.2.6 on 2019-10-17 11:35

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('history', '0003_history_fio'),
    ]

    operations = [
        migrations.AlterField(
            model_name='history',
            name='path',
            field=isc_common.fields.code_field.CodeStrictField(),
        ),
    ]
