# Generated by Django 2.2.4 on 2019-08-21 20:14

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0019_delete_holidays_view'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='shift_day',
            name='props',
        ),
    ]
