# Generated by Django 3.1.7 on 2021-03-15 11:54

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ('isc_common', '0085_user_e_mails_user_phones'),
    ]

    operations = [
        migrations.AddField(
            model_name='user_e_mails',
            name='props',
            field=bitfield.models.BitField((('main', 'Главная'),), db_index=True, default=0),
        ),
        migrations.AddField(
            model_name='user_phones',
            name='props',
            field=bitfield.models.BitField((('main', 'Главная'),), db_index=True, default=0),
        ),
    ]
