# Generated by Django 2.2.2 on 2019-06-16 04:50

from django.db import migrations
import django.db.models.manager


class Migration(migrations.Migration):

    dependencies = [
        ('one_c', '0008_auto_20190610_1556'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='files_1c',
            managers=[
                ('object', django.db.models.manager.Manager()),
            ],
        ),
    ]
