# Generated by Django 2.2.3 on 2019-07-02 12:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('refs', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='type_param',
            name='exponent',
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='type_param',
            name='length',
            field=models.PositiveIntegerField(blank=True, default=255, null=True),
        ),
        migrations.AlterField(
            model_name='type_param',
            name='precision',
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
    ]
