# Generated by Django 3.1.7 on 2021-03-15 09:22

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ('isc_common', '0082_auto_20210312_0927'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='users_images',
            name='club',
        ),
    ]
