# Generated by Django 3.1.7 on 2021-03-12 09:27

import django.db.models.deletion
from django.conf import settings
from django.db import migrations

import isc_common.fields.related


class Migration(migrations.Migration):
    dependencies = [
        ('isc_common', '0081_auto_20210310_0452'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='auditmodelex',
            name='updator',
        ),
        migrations.AddField(
            model_name='auditmodelex',
            name='editor',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='AuditModelEx_editor', to=settings.AUTH_USER_MODEL),
        ),
    ]
