# Generated by Django 3.1.6 on 2021-03-01 11:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0073_auto_20210301_1040'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user',
            name='real_name',
            field=models.TextField(blank=True, db_index=True, null=True, verbose_name='Первоначальное имя файла'),
        ),
    ]
