# Generated by Django 3.1.3 on 2020-11-20 13:16

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import isc_common.fields.code_field
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0055_auto_20200713_0552'),
    ]

    operations = [
        migrations.CreateModel(
            name='Last_used_processes',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('key', isc_common.fields.code_field.CodeField(blank=True, null=True)),
                ('process', models.BigIntegerField(db_index=True)),
                ('user', isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'Сохраненные параметры',
                'unique_together': {('user', 'key', 'process')},
            },
        ),
    ]
