# Generated by Django 3.0.3 on 2020-02-11 04:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0048_auto_20200211_0445'),
    ]

    operations = [
        migrations.AlterField(
            model_name='progresses',
            name='message',
            field=models.TextField(),
        ),
    ]
