# Generated by Django 3.1.7 on 2021-03-10 04:52

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('isc_common', '0080_auto_20210310_0443'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user',
            name='id',
            field=models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор'),
        ),
    ]
