# Generated by Django 2.2.4 on 2019-08-22 22:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0032_auto_20190822_2239'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='calendar_shifts_days',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='calendars',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='day',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='day_types',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='holidays',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='shift_day',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='shifts',
            name='id_old',
        ),
    ]
