# Generated by Django 3.1.7 on 2021-04-06 10:36

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ('isc_common', '0092_auto_20210406_1032'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='users_images',
            unique_together={('image', 'main_model', 'props')},
        ),
    ]
