# Generated by Django 3.1.7 on 2021-03-31 10:20

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        # ('competitions', '0235_auto_20210331_1020'),
        ('isc_common', '0090_auto_20210326_0949'),
    ]

    operations = [
        migrations.DeleteModel(
            name='AuditModelEx',
        ),
    ]
