# Generated by Django 3.2.3 on 2021-05-17 05:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0100_alter_images_attfile'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='image_types',
            name='sizes',
        ),
        migrations.AddField(
            model_name='image_types',
            name='height',
            field=models.SmallIntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='image_types',
            name='width',
            field=models.SmallIntegerField(blank=True, null=True),
        ),
    ]
