# Generated by Django 3.1.6 on 2021-02-15 06:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0059_auto_20210121_0639'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='birtdate',
            field=models.DateField(blank=True, null=True),
        ),
    ]
