# Generated by Django 2.2.6 on 2019-10-19 17:14

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0073_messagesthemeusersaccess'),
    ]

    operations = [
        migrations.AddField(
            model_name='messagesthemeusersaccess',
            name='props',
            field=bitfield.models.BitField((('all_content', 'Доступ ко всем делам данной темы'),), db_index=True, default=0),
        ),
    ]
