# Generated by Django 2.2.2 on 2019-06-10 15:30

from django.db import migrations, models
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('one_c', '0004_auto_20190526_1042'),
    ]

    operations = [
        migrations.AlterField(
            model_name='documents_param_1c',
            name='document',
            field=isc_common.fields.related.ForeignKeyCascade(default=None, on_delete=django.db.models.deletion.CASCADE, to='one_c.Document_1c'),
        ),
        migrations.CreateModel(
            name='Documents_param_cross_1c',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('document', isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='one_c.Document_1c')),
                ('param', isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='one_c.Documents_param_1c')),
            ],
            options={
                'verbose_name': 'Кросс таблица',
            },
        ),
    ]
