# Generated by Django 3.1.5 on 2021-01-21 06:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('isc_common', '0058_auto_20210121_0633'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='debug',
            name='deleted_at',
        ),
        migrations.RemoveField(
            model_name='debug',
            name='deliting',
        ),
        migrations.RemoveField(
            model_name='debug',
            name='editing',
        ),
        migrations.RemoveField(
            model_name='debug',
            name='lastmodified',
        ),
        migrations.AddField(
            model_name='debug',
            name='params',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='debug',
            name='id',
            field=models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
    ]
